Class: Azure::EventGrid::V2018_01_01::Models::AppConfigurationKeyValueModifiedEventData

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2018-01-01/generated/azure_event_grid/models/app_configuration_key_value_modified_event_data.rb

Overview

Schema of the Data property of an EventGridEvent for an Microsoft.AppConfiguration.KeyValueModified event.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#etagString

Returns The etag representing the new state of the key-value.

Returns:

  • (String)

    The etag representing the new state of the key-value.



25
26
27
# File 'lib/2018-01-01/generated/azure_event_grid/models/app_configuration_key_value_modified_event_data.rb', line 25

def etag
  @etag
end

#keyString

modified.

Returns:

  • (String)

    The key used to identify the key-value that was



18
19
20
# File 'lib/2018-01-01/generated/azure_event_grid/models/app_configuration_key_value_modified_event_data.rb', line 18

def key
  @key
end

#labelString

was modified.

Returns:

  • (String)

    The label, if any, used to identify the key-value that



22
23
24
# File 'lib/2018-01-01/generated/azure_event_grid/models/app_configuration_key_value_modified_event_data.rb', line 22

def label
  @label
end

Class Method Details

.mapperObject

Mapper for AppConfigurationKeyValueModifiedEventData class as Ruby Hash. This will be used for serialization/deserialization.



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/2018-01-01/generated/azure_event_grid/models/app_configuration_key_value_modified_event_data.rb', line 33

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'AppConfigurationKeyValueModifiedEventData',
    type: {
      name: 'Composite',
      class_name: 'AppConfigurationKeyValueModifiedEventData',
      model_properties: {
        key: {
          client_side_validation: true,
          required: false,
          serialized_name: 'key',
          type: {
            name: 'String'
          }
        },
        label: {
          client_side_validation: true,
          required: false,
          serialized_name: 'label',
          type: {
            name: 'String'
          }
        },
        etag: {
          client_side_validation: true,
          required: false,
          serialized_name: 'etag',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end